<?php
/**
 * @author Thomas Müller <thomas.mueller@tmit.eu>
 *
 * @copyright Copyright (c) 2015, ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\password_policy;

use OCA\password_policy\Rules\Length;
use OCA\password_policy\Rules\Numbers;
use OCA\password_policy\Rules\Special;
use OCA\password_policy\Rules\Uppercase;

class Engine {

	private $configValues;

	public function __construct(array $configValues) {
		$this->configValues = $configValues;
	}

	public function verifyPassword($password) {
		if ($this->yes('spv_min_chars_checked')) {
			$val = $this->configValues['spv_min_chars_value'];
			$r = new Length();
			$r->verify($password, $val);
		}
		if ($this->yes('spv_uppercase_checked')) {
			$val = $this->configValues['spv_uppercase_value'];
			$r = new Uppercase();
			$r->verify($password, $val);
		}
		if ($this->yes('spv_numbers_checked')) {
			$val = $this->configValues['spv_numbers_value'];
			$r = new Numbers();
			$r->verify($password, $val);
		}
		if ($this->yes('spv_special_chars_checked')) {
			$val = $this->configValues['spv_special_chars_value'];
			$chars = [];
			if ($this->yes('spv_def_special_chars_checked')) {
				$chars = $this->configValues['spv_def_special_chars_value'];
			}
			$r = new Special();
			$r->verify($password, $val, $chars);
		}
	}

	/**
	 * @return bool
	 */
	private function yes($key) {
		if ($this->configValues[$key] === 'on') {
			return true;
		}
		return $this->configValues[$key];
	}
}

