<?php
/**
 * @author Thomas Müller <thomas.mueller@tmit.eu>
 *
 * @copyright Copyright (c) 2015, ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\password_policy;

use Exception;

class HooksHandler {

	public static function verifyPassword($params) {

		$configValues = self::loadConfiguration();

		$engine = new Engine($configValues);

		try {
			$engine->verifyPassword($params['password']);
			$params['accepted'] = true;
			$params['message'] = '';
		} catch (Exception $ex) {
			$params['accepted'] = false;
			$params['message'] = $ex->getMessage();
		}
	}

	public static function applyLinkExpiry($params) {
		$configValues = self::loadConfiguration();

		if (isset($params['shareWith'])) {
			if ($configValues['spv_expiration_password_checked'] === 'on') {
				$days = $configValues['spv_expiration_password_value'];
				$date = Date('d-m-Y', strtotime("+$days days"));
				\OCP\Share::setExpirationDate($params['itemType'], $params['itemSource'], $date);
			}
		} else {
			if ($configValues['spv_expiration_nopassword_checked'] === 'on') {
				$days = $configValues['spv_expiration_nopassword_value'];
				$date = Date('d-m-Y', strtotime("+$days days"));
				\OCP\Share::setExpirationDate($params['itemType'], $params['itemSource'], $date);
			}
		}
	}

	/**
	 * @return array
	 */
	private static function loadConfiguration() {
		$appValues = [
			'spv_min_chars_checked' => false,
			'spv_min_chars_value' => 8,
			'spv_uppercase_checked' => false,
			'spv_uppercase_value' => 1,
			'spv_numbers_checked' => false,
			'spv_numbers_value' => 1,
			'spv_special_chars_checked' => false,
			'spv_special_chars_value' => 1,
			'spv_def_special_chars_checked' => false,
			'spv_def_special_chars_value' => '#!',
			'spv_expiration_password_checked' => false,
			'spv_expiration_password_value' => 7,
			'spv_expiration_nopassword_checked' => false,
			'spv_expiration_nopassword_value' => 7,
		];

		$configValues = [];
		foreach ($appValues as $key => $default) {
			$configValues[$key] = \OC::$server->getConfig()->getAppValue('password_policy', $key, $default);
		}
		return $configValues;
	}
}
