<?php
/**
 * @author Thomas Müller <thomas.mueller@tmit.eu>
 *
 * @copyright Copyright (c) 2015, ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\password_policy\Rules;

class Special {

	/**
	 * @param string $password
	 * @param string $val
	 * @param string $allowedSpecialChars
	 * @throws \Exception
	 */
	public function verify($password, $val, $allowedSpecialChars) {
		$special = $this->stripAlphaNumeric($password);
		if (!empty($allowedSpecialChars) && !empty($special)) {
			$allowedSpecialCharsAsArray = str_split($allowedSpecialChars);
			$s = array_filter(str_split($special), function($char) use ($allowedSpecialCharsAsArray){
				return !(in_array($char, $allowedSpecialCharsAsArray, true));
			});
			if (count($s) > 0) {
				throw new \Exception("Password holds invalid special characters. Only $allowedSpecialChars as allowed");
			}
		}
		if (strlen($special) < $val) {
			throw new \Exception("Password holds too less special characters. Minimum $val special characters are required.");
		}
	}

	private function stripAlphaNumeric( $string ) {
		return preg_replace( "/[a-z0-9]/i", "", $string );
	}

}

