<?php
/**
 * @author Thomas Müller <thomas.mueller@tmit.eu>
 *
 * @copyright Copyright (c) 2015, ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

use OCA\password_policy\Rules\Special;

class SpecialTest extends \PHPUnit_Framework_TestCase {

	/**
	 * @expectedException Exception
	 */
	public function testTooShort() {
		$r = new Special();
		$r->verify('', 4, []);
	}

	/**
	 * @dataProvider providesTestData
	 */
	public function testOkay($password, $val, $allowedSpecialChars) {
		$r = new Special();
		$r->verify($password, $val, $allowedSpecialChars);
	}

	/**
	 * @dataProvider providesExceptionalData
	 */
	public function testInvalidSpecial($expectedMessage, $password, $val, $allowedSpecialChars) {
		try {
			$r = new Special();
			$r->verify($password, $val, $allowedSpecialChars);
			$this->fail('');
		} catch (Exception $ex) {
			$this->assertEquals($expectedMessage, $ex->getMessage());
		}
	}

	function providesExceptionalData() {
		return [
			['Password holds invalid special characters. Only #+ as allowed', '#+?@#+?@', 4, '#+'],
			['Password holds too less special characters. Minimum 9 special characters are required.', '#+?@#+?@', 9, []],
			['Password holds too less special characters. Minimum 10 special characters are required.', '#+?@#+?@', 10, '#+?@'],
			['Password holds too less special characters. Minimum 2 special characters are required.', '#', 2, '#!'],
			['Password holds too less special characters. Minimum 1 special characters are required.', 'qaa', 1, '#!']
		];
	}

	function providesTestData() {
		return [
			['#+?@#+?@', 6, []],
			['#+?@#+?@', 6, '#+?@'],
			['#', 1, '#!']
		];
	}
}
